pub enum ConnectivityStatus {
Initializing,
Online(usize),
Degraded(usize),
Offline,
}Expand description
Node connectivity status.
Variants
Initializing
Initial connectivity status before the Connectivity actor has initialized.
Online(usize)
Connectivity is online.
Degraded(usize)
Connectivity is less than the required minimum, but some connections are still active.
Offline
There are no active connections.
Implementations
Sourceimpl ConnectivityStatus
impl ConnectivityStatus
pub fn is_initializing(&self) -> bool
pub fn is_online(&self) -> bool
pub fn is_offline(&self) -> bool
pub fn is_degraded(&self) -> bool
pub fn num_connected_nodes(&self) -> usize