pub struct MemorySocket { /* private fields */ }Expand description
An in-memory stream between two local sockets.
A MemorySocket can either be created by connecting to an endpoint, via the
connect method, or by accepting a connection from a listener.
It can be read or written to using the AsyncRead, AsyncWrite, and related
extension traits in futures::io.
Examples
use futures::prelude::*;
use tari_comms::memsocket::MemorySocket;
use tokio::io::*;
let (mut socket_a, mut socket_b) = MemorySocket::new_pair();
socket_a.write_all(b"stormlight").await?;
socket_a.flush().await?;
let mut buf = [0; 10];
socket_b.read_exact(&mut buf).await?;
assert_eq!(&buf, b"stormlight");
Implementations
Sourceimpl MemorySocket
impl MemorySocket
Sourcepub fn new_pair() -> (Self, Self)
pub fn new_pair() -> (Self, Self)
Construct both sides of an in-memory socket.
Examples
use tari_comms::memsocket::MemorySocket;
let (socket_a, socket_b) = MemorySocket::new_pair();Sourcepub fn connect(port: u16) -> Result<MemorySocket>
pub fn connect(port: u16) -> Result<MemorySocket>
Create a new in-memory Socket connected to the specified port.
This function will create a new MemorySocket socket and attempt to connect it to
the port provided.
Examples
use tari_comms::memsocket::MemorySocket;
let socket = MemorySocket::connect(16)?;Trait Implementations
Sourceimpl AsyncRead for MemorySocket
impl AsyncRead for MemorySocket
Sourceimpl AsyncWrite for MemorySocket
impl AsyncWrite for MemorySocket
Sourcefn poll_write(
self: Pin<&mut Self>,
cx: &mut Context<'_>,
buf: &[u8],
) -> Poll<Result<usize>>
fn poll_write( self: Pin<&mut Self>, cx: &mut Context<'_>, buf: &[u8], ) -> Poll<Result<usize>>
Attempt to write bytes from buf into the outgoing channel.
Sourcefn poll_flush(self: Pin<&mut Self>, _: &mut Context<'_>) -> Poll<Result<()>>
fn poll_flush(self: Pin<&mut Self>, _: &mut Context<'_>) -> Poll<Result<()>>
Attempt to flush the channel. Cannot Fail.
Sourcefn poll_shutdown(self: Pin<&mut Self>, _: &mut Context<'_>) -> Poll<Result<()>>
fn poll_shutdown(self: Pin<&mut Self>, _: &mut Context<'_>) -> Poll<Result<()>>
Attempt to close the channel. Cannot Fail.
Sourcefn poll_write_vectored(
self: Pin<&mut Self>,
cx: &mut Context<'_>,
bufs: &[IoSlice<'_>],
) -> Poll<Result<usize, Error>>
fn poll_write_vectored( self: Pin<&mut Self>, cx: &mut Context<'_>, bufs: &[IoSlice<'_>], ) -> Poll<Result<usize, Error>>
Like
poll_write, except that it writes from a slice of buffers. Read moreSourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
Determines if this writer has an efficient
poll_write_vectored
implementation. Read moreAuto Trait Implementations
impl !Freeze for MemorySocket
impl !RefUnwindSafe for MemorySocket
impl Send for MemorySocket
impl Sync for MemorySocket
impl Unpin for MemorySocket
impl !UnwindSafe for MemorySocket