PeerFeatures

Struct PeerFeatures 

pub struct PeerFeatures(/* private fields */);
Peer feature flags. These advertised the capabilities of peer nodes.

Implementations

Source

impl PeerFeatures

pub const NONE: Self

No capabilities

pub const MESSAGE_PROPAGATION: Self

Node is able to propagate messages

pub const DHT_STORE_FORWARD: Self

Legacy compatibility for nodes that used to offer store and forward functionality; this is no longer used, but it will change the node’s public key if it is not present.

pub const COMMUNICATION_NODE: Self

Node is a communication node (typically a base layer node)

pub const COMMUNICATION_CLIENT: Self

Node is a network client

Source

impl PeerFeatures

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl PeerFeatures

pub const fn iter(&self) -> Iter<PeerFeatures>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<PeerFeatures>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl PeerFeatures

pub fn is_client(self) -> bool

Returns true if these flags represent a COMMUNICATION_CLIENT.

pub fn is_node(self) -> bool

Returns true if these flags represent a COMMUNICATION_NODE.

pub fn as_role_str(self) -> &'static str

Returns a human-readable string that represents these flags.

pub fn to_i32(&self) -> i32

Returns the bits of the PeerFeatures as an i32